OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> para ficheiros",
    "%1$s commented" : "%1$s comentou",
    "%1$s commented on %2$s" : "%1$s comentou %2$s",
    "Comments" : "Comentários",
    "Type in a new comment..." : "Escreva um novo comentário...",
    "Delete comment" : "Apagar comentário",
    "Post" : "Enviar",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentário",
    "[Deleted user]" : "[utilizador apagado]",
    "No other comments available" : "Nenhum outro comentário disponível",
    "More comments..." : "Mais comentários...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres restantes",
    "{count} unread comments" : "{count} comentários não lidos",
    "Comment" : "Comentário",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> para ficheiros"
},
"nplurals=2; plural=(n != 1);");
